<?php

namespace Drupal\seo_urls\EventSubscriber;

use Drupal\Core\Path\CurrentPathStack;
use Drupal\seo_urls\SeoUrlManager;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Symfony\Component\HttpKernel\KernelEvents;
use Symfony\Component\HttpKernel\Event\ControllerEvent;
use Symfony\Component\HttpKernel\Event\TerminateEvent;

/**
 * Provides a path subscriber that converts SEO urls.
 */
class SeoUrlSubscriber implements EventSubscriberInterface {

  /**
   * Constructs a new SeoUrlSubscriber instance.
   *
   * @param \Drupal\seo_urls\SeoUrlManager $seoUrlManager
   *   SEO url manager.
   * @param \Drupal\Core\Path\CurrentPathStack $currentPath
   *   The current path.
   */
  public function __construct(protected SeoUrlManager $seoUrlManager, protected CurrentPathStack $currentPath) {}

  /**
   * Sets the cache key on the Seo Url manager cache decorator.
   *
   * KernelEvents::CONTROLLER is used in order to be executed after routing.
   *
   * @param \Symfony\Component\HttpKernel\Event\ControllerEvent $event
   *   The Event to process.
   */
  public function onKernelController(ControllerEvent $event) {
    // Set the cache key on the alias manager cache decorator.
    if ($event->isMainRequest()) {
      $this->seoUrlManager->setCacheKey(rtrim($this->currentPath->getPath($event->getRequest()), '/'));
    }
  }

  /**
   * Ensures system paths for the request get cached.
   */
  public function onKernelTerminate(TerminateEvent $event) {
    $this->seoUrlManager->writeCache();
  }

  /**
   * Registers the methods in this class that should be listeners.
   *
   * @return array
   *   An array of event listener definitions.
   */
  public static function getSubscribedEvents() {
    $events[KernelEvents::CONTROLLER][] = ['onKernelController', 200];
    $events[KernelEvents::TERMINATE][] = ['onKernelTerminate', 200];
    return $events;
  }

}
